﻿©Fluke                                                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek TDSxxx Record Reading IEEE
INSTRUMENT:            Sub Tek TDSxxx Cursor Walker IEEE
INSTRUMENT:            Sub Tek TDSxxx Main Trigger IEEE
INSTRUMENT:            Sub Tek TDSxxx Delay Trigger IEEE
INSTRUMENT:            Sub Tek TDSxxx Cursor Reading IEEE
INSTRUMENT:            Sub Tek TDSxxx Check for Trigger IEEE
DATE:                  2010-06-22 12:37:14
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       8
NUMBER OF LINES:       367
=============================================================================
#
#  Procedure Author:  DAC, VY
#
#  Model(s) Covered:  TDS Series
#
#  Compatibility:     MET/CAL 7.20 SP1 (7.20x) or later
#
#  Subprocedures:     None
#
#  Required Files:    None
#
#  Additional Equipment Required:
#                     None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
# REGISTERS USED:
#
#   You will notice that MEM & MEM1 are used extensively in this procedure.
#   This can be dangerous to use since MEM and MEM1 are used for controlling
#   instruments.  We read the values from MEM and MEM1 and store these in
#   temporary registers which are later restored on exiting the sub-procedure.
#
#   L[3]
#     This register is the horizontal position for the Cursor Walker
#     subprocedure.
#
#   M[10]
#     This variable is used to set watchdog timer in the event the
#     oscilloscope does not respond to a command.
#
#   L[31]
#     This variable is used to store the value of MEM
#
#   L[32]
#     This variable is used to store the value of MEM1
#
#   M[20]
#     This variable to designate Main (=0) vs Delay (=1) trigger adjust
#
#   M[1]
#     This register is the horizontal start position for the Cursor Walker
#     subprocedure.
#
#   M[2]
#     This register is the horizontal increment for the Cursor Walker
#     subprocedure.
#
#   M[3]
#     This register is the starting trigger level for the Main Trigger
#     and Delay Trigger subprocedures.
#
#   M[4]
#     This register is the target for the cursor walker, or the trigger
#     level increment for the Main Trigger and Delay Trigger subprocedures.
#
#   S[6]
#     This variable is used to store the trigger "MAIN" or "DELAY".
#
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Backup MEM and MEM1
  1.001  MATH         L[31] = MEM; L[32] = MEM1

# MET/CAL 7.0 or later.
  1.002  JMPL         RECORD_READING               PSUBI("Record Reading")
  1.003  JMPL         CURSOR_WALKER                PSUBI("Cursor Walker")
  1.004  JMPL         MAIN_TRIGGER                 PSUBI("Main Trigger")
  1.005  JMPL         DELAY_TRIGGER                PSUBI("Delay Trigger")
  1.006  JMPL         CURSOR_READING               PSUBI("Cursor Reading")
  1.007  JMPL         CHECK_FOR_TRIGGER            PSUBI("Check for Trigger")
  1.008  DISP         Undefined subprocedure!
  1.009  END

  1.010  EVAL   dummy

# ************************* RECORD READING *******************************

# Reset the watchdog counter
  2.001  LABEL        RECORD_READING
# We picked a value of 5 times the resolution of the measurement to determine
# a stable reading.  Other factors like noise or condition of the scope will
# have a factor in this.
  2.002  MATH         L[17] = 5 * M[17]
  2.003  MATH         M[10] = 0

  2.004  DO
# We will go through this loop 50 times.  If there is not a good reading
# then we will warn the operator
  2.005  MATH         M[10] = M[10] + 1

  2.006  IF           M[10] > 50
  2.007  OPBR         50 readings have been taken and three sequential
  2.007  OPBR         readings are not stable to within [L17].
  2.007  OPBR
  2.007  OPBR         Do you wish to take more readings?
  2.008  JMPL         TAKE_READING                 MEM1 < 0
  2.009  MATH         M[10] = 0
  2.010  ENDIF

# Take three readings.
  2.011  IEEE         ACQUIRE:STATE RUN
  2.012  IEEE         [SREG5][I][D50]
  2.013  MATH         L[14] = MEM
  2.014  HEAD         Channel Reading = [MEM]
  2.015  WAIT         [D350]
  2.016  IEEE         ACQUIRE:STATE RUN
  2.017  IEEE         [SREG5][I][D50]
  2.018  MATH         L[15] = MEM
  2.019  HEAD         Channel Reading = [MEM]
  2.020  WAIT         [D350]
  2.021  IEEE         ACQUIRE:STATE RUN
  2.022  IEEE         [SREG5][I][D50]
  2.023  HEAD         Channel Reading = [MEM]
  2.024  MATH         L[16] = MEM
# Computer maximum and minimum of the three readings.
  2.025  MATH         L[18] = MIN_L(14, 16); L[19] = MAX_L(14, 16)
  2.026  UNTIL        ABS(L[18] - L[19]) <= L[17]

# Take one more reading and use it
  2.027  LABEL        TAKE_READING
  2.028  IEEE         ACQUIRE:STATE RUN
  2.029  IEEE         [SREG5][I][D50]
  2.030  HEAD         Channel Reading = [MEM]
# Note, MEM is restored from L[31] at bottom of this procedure.
  2.031  MATH         L[31] = MEM
  2.032  JMPL         RESTORE_MEM_AND_MEM1

  2.033  EVAL   dummy

# ******************** Cursor "Walking" Routine **************************

# This function moves cursor 1 a step at a time until it finds the target
# amplitude of the waveform specified in M[4]. It "returns" a value in
# MEM that is equal to the time at which the amplitude happens.

  3.001  LABEL        CURSOR_WALKER
# Initialize horizontal position (s).
  3.002  MATH         L[3] = M[1]
  3.003  IEEE         [T120000]CURSOR:PAIRED:POSITION1 [L3]
  3.004  WAIT         [D3000]
  3.005  IEEE         CURSOR:PAIRED:HPOS1?[I][D50]

  3.006  DO
# Save vertical amplitude for next iteration.
  3.007  MATH         L[5] = MEM
# Increment the horizontal position.
  3.008  MATH         L[3] = L[3] + M[2]
# Move the cursor to the horizontal position.
  3.009  IEEE         CURSOR:PAIRED:POSITION1 [L3]
  3.010  WAIT         [D50]
# Read the vertical amplitude.
  3.011  IEEE         CURSOR:PAIRED:HPOS1?[I][D50]
# If vertical amplitude has passed the target value, exit the loop.
  3.012  UNTIL        MEM > M[4]

# If previous amplitude was closer to the target, use it.
  3.013  IF           ABS(L[5] - M[4]) < ABS(MEM - M[4])
  3.014  MATH         L[3] = L[3] - M[2]; MEM = L[5]
  3.015  ENDIF

# Debug statements.
# 3.020  MATH         S[20] = FMT((L[3] / 1E-12), "%.1f")
# 3.021  MATH         S[21] = FMT((MEM / 1E-3), "%.2f")
# 3.022  DISP         Horz. Pos. [S20] ps, Vert. Ampl. [S21] mV, Limit [M4] V
# Note, MEM is restored from L[31] at bottom of this procedure.
  3.016  MATH         L[31] = L[3]
  3.017  JMPL         RESTORE_MEM_AND_MEM1

  3.018  EVAL   dummy

# ****************************** MAIN TRIGGER ********************************

  4.001  LABEL        MAIN_TRIGGER
  4.002  MATH         M[20] = 0

  4.003  LABEL        CHECK_MAIN_TRIGGER
# Trigger Level we will start with
  4.004  IEEE         TRIGGER:MAIN SETLEVEL
  4.005  MATH         L[1] = 0; M[10] = 0
  4.006  IEEE         TRIGGER:MAIN:LEVEL [M3]

  4.007  LABEL        TEST_MAIN_LEVEL
# Increment Master Watchdog counter
  4.008  MATH         L[1] = L[1] + 1
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
  4.009  JMPL         FAIL_MAIN_TRIGGER            L[1] >= 100
  4.010  WAIT         [D250]
# Read the Trigger State
  4.011  IEEE         TRIGGER:STATE?[I$][D50]
  4.012  JMPL         PART_OR_TRIG                 M[20] > 0

# If MAIN TRIGGER was called directly the response must TRIGgered.
  4.013  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
  4.014  JMPL         CHECK_MAIN_RESPONSE

  4.015  LABEL        PART_OR_TRIG
# If MAIN TRIGGER was called from DELAY TRIGGER, PARTial or TRIGgered is ok.
  4.016  MATH         MEM1 = FIND(MEM2, "TRIG", 1) + FIND(MEM2, "PART", 1)

  4.017  LABEL        CHECK_MAIN_RESPONSE
  4.018  JMPL         ADJUST_MAIN_LEVEL            MEM1 < 1
# Increment the good trigger counter
  4.019  MATH         M[10] = M[10] + 1
# Jump out of the loop if the system records over 10 good triggers
  4.020  JMPL         END_MAIN_TRIGGER             M[10] > 10
# Go back to the trigger beginning
  4.021  JMPL         TEST_MAIN_LEVEL

  4.022  LABEL        ADJUST_MAIN_LEVEL
# Reset the good trigger counter
  4.023  MATH         M[10] = 0
# If we counted too high, start over
  4.024  JMPL         INCREMENT_MAIN_LEVEL         MEM < ABS(M[3])
  4.025  MATH         MEM = M[3]

  4.026  LABEL        INCREMENT_MAIN_LEVEL
  4.027  MATH         MEM = MEM + M[4]
  4.028  IEEE         TRIGGER:MAIN:LEVEL [MEM]
  4.029  HEAD         MAIN TRIGGER LEVEL: [MEM] V
  4.030  JMPL         TEST_MAIN_LEVEL

  4.031  LABEL        FAIL_MAIN_TRIGGER
# Set a value for M[10] which will later be evaluated as a failure
  4.032  MATH         M[10] = 0

  4.033  LABEL        END_MAIN_TRIGGER
  4.034  JMPL         CHECK_DELAY_TRIGGER          M[20] > 0
  4.035  JMPL         RESTORE_MEM_AND_MEM1

  4.036  EVAL   dummy

# ************************* DELAY TRIGGER ********************************

  5.001  LABEL        DELAY_TRIGGER
  5.002  MATH         M[20] = 1

  5.003  LABEL        CHECK_DELAY_TRIGGER
# Set a flag
  5.004  MATH         L[1] = 0; M[10] = 0
  5.005  IEEE         TRIGGER:DELAY:LEVEL [M3]

  5.006  LABEL        TEST_DELAY_LEVEL
# Increment Master Watchdog counter
  5.007  MATH         L[1] = L[1] + 1
  5.008  JMPL         FAIL_DELAY_TRIGGER           L[1] >= 100
  5.009  WAIT         [D250]
# Read the Trigger State
  5.010  IEEE         TRIGGER:STATE?[I$][D50]
# If "REAdy", we need to re-adjust the main trigger level.
  5.011  JMPL         CHECK_MAIN_TRIGGER           FIND(MEM2, "REA", 1)
  5.012  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
# If "PARTial", we need to adjust the delay trigger Level.
  5.013  JMPL         ADJUST_DELAY_LEVEL           FIND(MEM2, "PART", 1)
# Increment the good trigger counter
  5.014  MATH         M[10] = M[10] + 1
# Jump out of the loop if the system records over 10 good triggers
  5.015  JMPL         END_DELAY_TRIGGER            M[10] > 10
# Go back to the trigger beginning
  5.016  JMPL         TEST_DELAY_LEVEL

  5.017  LABEL        ADJUST_DELAY_LEVEL
# Reset the good trigger counter
  5.018  MATH         M[10] = 0
# If we counted too high, start over
  5.019  JMPL         DELAY_ADD_LEVEL              MEM < ABS(M[3])
  5.020  MATH         MEM = M[3]

  5.021  LABEL        DELAY_ADD_LEVEL
  5.022  MATH         MEM = MEM + M[4]
  5.023  IEEE         TRIGGER:DELAY:LEVEL [MEM]
  5.024  HEAD         DELAY TRIGGER LEVEL: [MEM] V
  5.025  JMPL         TEST_DELAY_LEVEL

  5.026  LABEL        FAIL_DELAY_TRIGGER
# Set a value for M[10] which will later be evaluated as a failure
  5.027  MATH         M[10] = 0

  5.028  LABEL        END_DELAY_TRIGGER
  5.029  JMPL         RESTORE_MEM_AND_MEM1

  5.030  EVAL   dummy

# ************************* CURSOR_READING *******************************

  6.001  LABEL        CURSOR_READING
  6.002  IEEE         ACQUIRE:STATE RUN
  6.003  IEEE         [SREG5][I][D50]
  6.004  MATH         L[14] = MEM
  6.005  HEAD         Channel Reading = [MEM]
  6.006  WAIT         [D350]
  6.007  IEEE         ACQUIRE:STATE RUN
  6.008  IEEE         [SREG5][I][D50]
  6.009  MATH         L[15] = MEM
  6.010  HEAD         Channel Reading = [MEM]
  6.011  WAIT         [D350]
  6.012  IEEE         ACQUIRE:STATE RUN
  6.013  IEEE         [SREG5][I][D50]
  6.014  HEAD         Channel Reading = [MEM]
  6.015  MATH         L[16] = MEM
  6.016  MATH         L[18] = MIN_L(14, 16); L[19] = MAX_L(14, 16)
  6.017  MATH         L[31] = L[19]
  6.018  JMPL         RESTORE_MEM_AND_MEM1

  6.019  EVAL   dummy

# *************************** CHECK FOR TRIGGER *****************************

# Wait up to 5s for UUT to trigger.

  7.001  LABEL        CHECK_FOR_TRIGGER
  7.002  MATH         M[10] = 0

  7.003  DO
  7.004  IEEE         TRIGGER:STATE?[I$][D50]
  7.005  MATH         L[32] = FIND(MEM2, "TRIG", 1)

  7.006  IF           L[32] == 0
  7.007  WAIT         [D1000]
  7.008  MATH         M[10] = M[10] + 1
  7.009  ENDIF

  7.010  UNTIL        (M[10] > 5) || (L[32] > 0)

  7.011  JMPL         RESTORE_MEM_AND_MEM1

  7.012  EVAL   dummy

# ************************* END OF PROCEDURES ****************************

  8.001  LABEL        RESTORE_MEM_AND_MEM1
  8.002  MATH         MEM = L[31]; MEM1 = L[32]
  8.003  END
